@@ -5,7 +5,7 @@ use warnings;
 use Class::Accessor::Lite (
     new => 1,
     rw  => [ qw/result_count total_count first_position items
-                is_success cause last_response/ ],
+                is_success cause/ ],
 );
 
 1;
@@ -46,10 +46,6 @@ WebService::DMM::Response is
 
 Cause of failing to request Web API,
 
-=item last_response : Furl::Response
-
-Return last response which is a Furl::Response instance.
-
 =back
 
 =head1 AUTHOR
